@@ -1,5 +1,3 @@
-# coding=utf-8
-
 """
 the views
 """
@@ -18,7 +16,6 @@ from aasrp import __title__
 from aasrp.app_settings import (
     AASRP_SRP_TEAM_DISCORD_CHANNEL,
     avoid_cdn,
-    discord_bot_active,
     get_site_url,
 )
 from aasrp.constants import SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE
@@ -30,12 +27,17 @@ from aasrp.helper.icons import (
     get_srp_request_status_icon,
     get_srp_request_action_icons,
 )
+from aasrp.helper.notification import (
+    send_user_notification,
+    send_message_to_discord_channel,
+)
 from aasrp.form import (
     AaSrpLinkForm,
     AaSrpLinkUpdateForm,
     AaSrpRequestForm,
     AaSrpRequestPayoutForm,
     AaSrpRequestRejectForm,
+    AaSrpUserSettingsForm,
 )
 from aasrp.managers import AaSrpManager
 from aasrp.models import (
@@ -45,13 +47,13 @@ from aasrp.models import (
     AaSrpRequestStatus,
     AaSrpStatus,
     AaSrpRequest,
+    AaSrpUserSettings,
 )
 from aasrp.utils import LoggerAddTag
 
 from eveuniverse.models import EveType
 
 from allianceauth.eveonline.models import EveCharacter
-from allianceauth.notifications import notify
 from allianceauth.services.hooks import get_extension_logger
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
@@ -67,6 +69,32 @@ def dashboard(request: WSGIRequest, show_all_links: bool = False) -> HttpRespons
     :return:
     """
 
+    # check if the current user has any settings. if not, create the default set
+    try:
+        user_settings = AaSrpUserSettings.objects.get(user=request.user)
+    except AaSrpUserSettings.DoesNotExist:
+        # create the default settings in the DB for the current user
+        user_settings = AaSrpUserSettings()
+        user_settings.user = request.user
+        user_settings.save()
+
+        # get the user settings again
+        user_settings = AaSrpUserSettings.objects.get(user=request.user)
+
+    # if this is a POST request we need to process the form data
+    if request.method == "POST":
+        user_settings_form = AaSrpUserSettingsForm(request.POST, instance=user_settings)
+
+        # check whether it's valid:
+        if user_settings_form.is_valid():
+            # user_settings.user = request.user
+            user_settings.disable_notifications = user_settings_form.cleaned_data[
+                "disable_notifications"
+            ]
+            user_settings.save()
+    else:
+        user_settings_form = AaSrpUserSettingsForm(instance=user_settings)
+
     logger_message = "Dashboard with available SRP links called by {user}".format(
         user=request.user
     )
@@ -77,7 +105,11 @@ def dashboard(request: WSGIRequest, show_all_links: bool = False) -> HttpRespons
 
     logger.info(logger_message)
 
-    context = {"avoid_cdn": avoid_cdn(), "show_all_links": show_all_links}
+    context = {
+        "avoid_cdn": avoid_cdn(),
+        "show_all_links": show_all_links,
+        "user_settings_form": user_settings_form,
+    }
 
     return render(request, "aasrp/dashboard.html", context)
 
@@ -454,9 +486,7 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
                 )
 
                 # send message to the srp team in their discord channel
-                if AASRP_SRP_TEAM_DISCORD_CHANNEL is not None and discord_bot_active():
-                    import aadiscordbot.tasks
-
+                if AASRP_SRP_TEAM_DISCORD_CHANNEL is not None:
                     site_base_url = get_site_url()
 
                     message = "**New SRP Request**\n\n"
@@ -478,22 +508,21 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
                             additional_information=srp_request_comment.comment
                         )
                     )
-
                     message += "**SRP Code:** {srp_code}\n".format(srp_code=srp_code)
                     message += "**SRP Link:** {srp_link}\n".format(
                         srp_link=site_base_url
                         + reverse("aasrp:view_srp_requests", args=[srp_link.srp_code])
                     )
 
+                    send_message_to_discord_channel(
+                        channel_id=AASRP_SRP_TEAM_DISCORD_CHANNEL, message=message
+                    )
+
                     logger.info(
                         "Sending SRP request notification to "
                         "the SRP team channel on Discord"
                     )
 
-                    aadiscordbot.tasks.send_channel_message_by_discord_id.delay(
-                        AASRP_SRP_TEAM_DISCORD_CHANNEL, message, embed=False
-                    )
-
                 return redirect("aasrp:dashboard")
             else:
                 messages.error(
@@ -970,34 +999,30 @@ def ajax_srp_request_approve(
         if request.user.profile.main_character:
             request_reviser = request.user.profile.main_character.character_name
 
-        notification_message = (
-            "Your SRP request regarding your {ship_name} lost during "
-            "{fleet_name} has been approved.\n\n"
-            "Request Details:\nSRP-Code: {srp_code}\n"
-            "Request-Code: {request_code}\n"
-            "Reviser: {reviser}\n\n{inquiry_note}".format(
-                ship_name=srp_request.ship.name,
-                fleet_name=srp_request.srp_link.srp_name,
-                srp_code=srp_request.srp_link.srp_code,
-                request_code=srp_request.request_code,
-                reviser=request_reviser,
-                inquiry_note=SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE,
+        user_settings = AaSrpUserSettings.objects.get(user=request.user)
+
+        # check if the user has notifications activated (it's by default)
+        if user_settings.disable_notifications is False:
+            notification_message = (
+                "Your SRP request regarding your {ship_name} lost during "
+                "{fleet_name} has been approved.\n\n"
+                "Request Details:\nSRP-Code: {srp_code}\n"
+                "Request-Code: {request_code}\n"
+                "Reviser: {reviser}\n\n{inquiry_note}".format(
+                    ship_name=srp_request.ship.name,
+                    fleet_name=srp_request.srp_link.srp_name,
+                    srp_code=srp_request.srp_link.srp_code,
+                    request_code=srp_request.request_code,
+                    reviser=request_reviser,
+                    inquiry_note=SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE,
+                )
             )
-        )
 
-        notify(
-            user=requester,
-            title=_("SRP Request Approved"),
-            level="success",
-            message=notification_message,
-        )
-
-        # send a PM to the user on Discord if allianceauth-discordbot is active
-        if discord_bot_active():
-            import aadiscordbot.tasks
-
-            aadiscordbot.tasks.send_direct_message_by_user_id.delay(
-                requester.pk, notification_message
+            send_user_notification(
+                user=requester,
+                level="success",
+                title=_("SRP Request Approved"),
+                message=notification_message,
             )
 
         data.append({"success": True, "message": _("SRP request has been approved")})
@@ -1056,36 +1081,32 @@ def ajax_srp_request_deny(
                 if request.user.profile.main_character:
                     request_reviser = request.user.profile.main_character.character_name
 
-                notification_message = (
-                    "Your SRP request regarding your {ship_name} lost during "
-                    "{fleet_name} has been rejected.\n\n"
-                    "Reason:\n{reject_info}\n\n"
-                    "Request Details:\nSRP-Code: {srp_code}\n"
-                    "Request-Code: {request_code}\n"
-                    "Reviser: {reviser}\n\n{inquiry_note}".format(
-                        ship_name=srp_request.ship.name,
-                        fleet_name=srp_request.srp_link.srp_name,
-                        reject_info=reject_info,
-                        srp_code=srp_request.srp_link.srp_code,
-                        request_code=srp_request.request_code,
-                        reviser=request_reviser,
-                        inquiry_note=SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE,
+                user_settings = AaSrpUserSettings.objects.get(user=request.user)
+
+                # check if the user has notifications activated (it's by default)
+                if user_settings.disable_notifications is False:
+                    notification_message = (
+                        "Your SRP request regarding your {ship_name} lost during "
+                        "{fleet_name} has been rejected.\n\n"
+                        "Reason:\n{reject_info}\n\n"
+                        "Request Details:\nSRP-Code: {srp_code}\n"
+                        "Request-Code: {request_code}\n"
+                        "Reviser: {reviser}\n\n{inquiry_note}".format(
+                            ship_name=srp_request.ship.name,
+                            fleet_name=srp_request.srp_link.srp_name,
+                            reject_info=reject_info,
+                            srp_code=srp_request.srp_link.srp_code,
+                            request_code=srp_request.request_code,
+                            reviser=request_reviser,
+                            inquiry_note=SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE,
+                        )
                     )
-                )
 
-                notify(
-                    user=requester,
-                    title=_("SRP Request Rejected"),
-                    level="danger",
-                    message=notification_message,
-                )
-
-                # send a PM to the user on Discord if allianceauth-discordbot is active
-                if discord_bot_active():
-                    import aadiscordbot.tasks
-
-                    aadiscordbot.tasks.send_direct_message_by_user_id.delay(
-                        requester.pk, notification_message
+                    send_user_notification(
+                        user=requester,
+                        level="danger",
+                        title=_("SRP Request Rejected"),
+                        message=notification_message,
                     )
 
                 data.append(
